MaterialResponsiveUiData class

A class that can be queried for breakpoints based on the guidelines in https://material.io/guidelines/layout/responsive-ui.html .

Properties

columns → int
Returns the recommended number of grid layout columns.
no setter
deviceInfo → MobileDeviceInfo
Returns the MobileDeviceInfo (type and symbolic size) for the device.
no setter
gutter → double
Returns the recommended gutter width, in logical pixels.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windowSize → VxWindowSize
Returns the symbolic window size of the device.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → MaterialResponsiveUiData