Nav<T extends StatefulWidget> mixin

Superclass constraints
Mixin applications

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setGlobalKey(GlobalKey<NavigatorState> key) → void
some library package need to change global key for some purpose. It is not recommended to change globalKey because it will reset all the navigation states.
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

globalContext → BuildContext
no setter
getter/setter pair

Static Methods

canPop({BuildContext? context}) → Future<bool>
Check if can pop
clearAll({BuildContext? context}) → void
clearAllAndPush<T>(Widget? screen, {BuildContext? context, NavAni navAni = NavAni.Fade, int durationMs = defaultDurationMs}) → Future<T?>
Clear All screen on navigator state and push the new one.
getPushRightRoute<T>(Widget screen, {bool prohibitSwipeBack = false, BuildContext? context, int durationMs = Nav.defaultDurationMs}) → Route<T>
initialize(NavSetting navSetting) → void
isCancel(dynamic result) → bool
Check result is cancel
isDeleted(dynamic result) → bool
Check result is deleted
isFail(dynamic result) → bool
Check result is fail
isRefresh(dynamic result) → bool
Check result is refresh
isSuccess(dynamic result) → bool
Check result is success
Get navigator state
pop<T>(BuildContext context, {T? result}) → void
pop screen with result
popResultCancel(BuildContext context) → void
simple pop with cancel result
popResultDelete(BuildContext context) → void
simple pop with delete result
popResultFail(BuildContext context) → void
simple pop with fail result
popResultRefresh(BuildContext context) → void
simple pop with refresh result
popResultSuccess(BuildContext context) → void
simple pop with success result
push<T>(Widget? screen, {NavAni navAni = NavAni.Right, BuildContext? context, int durationMs = defaultDurationMs}) → Future<T?>
Push screen with NavAni param
pushFromBottom<T>(Widget screen, {BuildContext? context}) → Future<T?>
Push screen from bottom to top
pushFromLeft<T>(Widget? screen, {BuildContext? context}) → Future<T?>
Push screen from left to right
pushFromRight<T>(Widget? screen, {bool prohibitSwipeBack = false, BuildContext? context}) → Future<T?>
Push screen from right to left
pushFromTop<T>(Widget screen, {BuildContext? context}) → Future<T?>
Push screen from top to bottom
pushReplacement<T, TO extends Object>(Widget? screen, {BuildContext? context, NavAni navAni = NavAni.Fade, TO? result, int durationMs = defaultDurationMs}) → Future<T?>
Push Replacement screen
pushResult<Result>(NavScreen<Result> screen, {NavAni navAni = NavAni.Right, BuildContext? context, int durationMs = defaultDurationMs}) → Future<Result?>
pushWithRippleEffect<T>(Widget? screen, {BuildContext? context, AlignmentGeometry? alignment, Offset offset = const Offset(0, 0), int durationMs = Nav.defaultDurationMs}) → Future<T?>
Push screen with Ripple Effect (Default: bottomRight to topLeft, You can change the alignment and offset)

Constants

CANCEL → const String
defaultDurationMs → const int
DELETED → const String
FAIL → const String
REFRESH → const String
RESULT → const String
SUCCESS → const String