RootBundleAssetLoader class

default used is RootBundleAssetLoader which uses flutter's assetloader

Inheritance

Constructors

RootBundleAssetLoader()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLocalePath(String basePath, Locale locale) → String
load(String path, Locale locale) → Future<Map<String, dynamic>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited