VelocityXTextSpan class

Constructors

VelocityXTextSpan(String _text)

Properties

amber100 → VelocityXTextSpan
no setterinherited
amber200 → VelocityXTextSpan
no setterinherited
amber300 → VelocityXTextSpan
no setterinherited
amber400 → VelocityXTextSpan
no setterinherited
amber50 → VelocityXTextSpan
Amber
no setterinherited
amber500 → VelocityXTextSpan
no setterinherited
amber600 → VelocityXTextSpan
no setterinherited
amber700 → VelocityXTextSpan
no setterinherited
amber800 → VelocityXTextSpan
no setterinherited
amber900 → VelocityXTextSpan
no setterinherited
black → VelocityXTextSpan
no setterinherited
blue100 → VelocityXTextSpan
no setterinherited
blue200 → VelocityXTextSpan
no setterinherited
blue300 → VelocityXTextSpan
no setterinherited
blue400 → VelocityXTextSpan
no setterinherited
blue50 → VelocityXTextSpan
Blue
no setterinherited
blue500 → VelocityXTextSpan
no setterinherited
blue600 → VelocityXTextSpan
no setterinherited
blue700 → VelocityXTextSpan
no setterinherited
blue800 → VelocityXTextSpan
no setterinherited
blue900 → VelocityXTextSpan
no setterinherited
bold → VelocityXTextSpan
Sets FontWeight to FontWeight.w700
no setter
capitalize → VelocityXTextSpan
Converts the text to first letter of very word as uppercase.
no setter
cyan100 → VelocityXTextSpan
no setterinherited
cyan200 → VelocityXTextSpan
no setterinherited
cyan300 → VelocityXTextSpan
no setterinherited
cyan400 → VelocityXTextSpan
no setterinherited
cyan50 → VelocityXTextSpan
Cyan
no setterinherited
cyan500 → VelocityXTextSpan
no setterinherited
cyan600 → VelocityXTextSpan
no setterinherited
cyan700 → VelocityXTextSpan
no setterinherited
cyan800 → VelocityXTextSpan
no setterinherited
cyan900 → VelocityXTextSpan
no setterinherited
emerald100 → VelocityXTextSpan
no setterinherited
emerald200 → VelocityXTextSpan
no setterinherited
emerald300 → VelocityXTextSpan
no setterinherited
emerald400 → VelocityXTextSpan
no setterinherited
emerald50 → VelocityXTextSpan
Emerald
no setterinherited
emerald500 → VelocityXTextSpan
no setterinherited
emerald600 → VelocityXTextSpan
no setterinherited
emerald700 → VelocityXTextSpan
no setterinherited
emerald800 → VelocityXTextSpan
no setterinherited
emerald900 → VelocityXTextSpan
no setterinherited
extraBlack → VelocityXTextSpan
Sets FontWeight to FontWeight.w900
no setter
extraBold → VelocityXTextSpan
Sets FontWeight to FontWeight.w800
no setter
fuchsia100 → VelocityXTextSpan
no setterinherited
fuchsia200 → VelocityXTextSpan
no setterinherited
fuchsia300 → VelocityXTextSpan
no setterinherited
fuchsia400 → VelocityXTextSpan
no setterinherited
fuchsia50 → VelocityXTextSpan
Fuchsia
no setterinherited
fuchsia500 → VelocityXTextSpan
no setterinherited
fuchsia600 → VelocityXTextSpan
no setterinherited
fuchsia700 → VelocityXTextSpan
no setterinherited
fuchsia800 → VelocityXTextSpan
no setterinherited
fuchsia900 → VelocityXTextSpan
no setterinherited
gray100 → VelocityXTextSpan
no setterinherited
gray200 → VelocityXTextSpan
no setterinherited
gray300 → VelocityXTextSpan
no setterinherited
gray400 → VelocityXTextSpan
no setterinherited
gray50 → VelocityXTextSpan
Gray
no setterinherited
gray500 → VelocityXTextSpan
no setterinherited
gray600 → VelocityXTextSpan
no setterinherited
gray700 → VelocityXTextSpan
no setterinherited
gray800 → VelocityXTextSpan
no setterinherited
gray900 → VelocityXTextSpan
no setterinherited
green100 → VelocityXTextSpan
no setterinherited
green200 → VelocityXTextSpan
no setterinherited
green300 → VelocityXTextSpan
no setterinherited
green400 → VelocityXTextSpan
no setterinherited
green50 → VelocityXTextSpan
Green
no setterinherited
green500 → VelocityXTextSpan
no setterinherited
green600 → VelocityXTextSpan
no setterinherited
green700 → VelocityXTextSpan
no setterinherited
green800 → VelocityXTextSpan
no setterinherited
green900 → VelocityXTextSpan
no setterinherited
hairLine → VelocityXTextSpan
Sets FontWeight to FontWeight.w100
no setter
hashCode → int
The hash code for this object.
no setterinherited
heightLoose → VelocityXTextSpan
Sets lineHeight to 1.5
no setter
heightRelaxed → VelocityXTextSpan
Sets lineHeight to 1.25
no setter
heightSnug → VelocityXTextSpan
Sets lineHeight to 0.875
no setter
heightTight → VelocityXTextSpan
Sets lineHeight to 0.75
no setter
hidePartial → VelocityXTextSpan
Converts the text to partially hideen text. Best for sensitive data.
no setter
indigo100 → VelocityXTextSpan
no setterinherited
indigo200 → VelocityXTextSpan
no setterinherited
indigo300 → VelocityXTextSpan
no setterinherited
indigo400 → VelocityXTextSpan
no setterinherited
indigo50 → VelocityXTextSpan
Indigo
no setterinherited
indigo500 → VelocityXTextSpan
no setterinherited
indigo600 → VelocityXTextSpan
no setterinherited
indigo700 → VelocityXTextSpan
no setterinherited
indigo800 → VelocityXTextSpan
no setterinherited
indigo900 → VelocityXTextSpan
no setterinherited
italic → VelocityXTextSpan
Sets FontStyle to FontStyle.italic
no setter
light → VelocityXTextSpan
Sets FontWeight to FontWeight.w300
no setter
lime100 → VelocityXTextSpan
no setterinherited
lime200 → VelocityXTextSpan
no setterinherited
lime300 → VelocityXTextSpan
no setterinherited
lime400 → VelocityXTextSpan
no setterinherited
lime50 → VelocityXTextSpan
Lime
no setterinherited
lime500 → VelocityXTextSpan
no setterinherited
lime600 → VelocityXTextSpan
no setterinherited
lime700 → VelocityXTextSpan
no setterinherited
lime800 → VelocityXTextSpan
no setterinherited
lime900 → VelocityXTextSpan
no setterinherited
lineThrough → VelocityXTextSpan
Sets TextDecoration as TextDecoration.lineThrough
no setter
lowercase → VelocityXTextSpan
Converts the text to fully lowercase.
no setter
medium → VelocityXTextSpan
Sets FontWeight to FontWeight.w500
no setter
neutral100 → VelocityXTextSpan
no setterinherited
neutral200 → VelocityXTextSpan
no setterinherited
neutral300 → VelocityXTextSpan
no setterinherited
neutral400 → VelocityXTextSpan
no setterinherited
neutral50 → VelocityXTextSpan
Neutral
no setterinherited
neutral500 → VelocityXTextSpan
no setterinherited
neutral600 → VelocityXTextSpan
no setterinherited
neutral700 → VelocityXTextSpan
no setterinherited
neutral800 → VelocityXTextSpan
no setterinherited
neutral900 → VelocityXTextSpan
no setterinherited
normal → VelocityXTextSpan
Sets FontWeight to FontWeight.w400
no setter
orange100 → VelocityXTextSpan
no setterinherited
orange200 → VelocityXTextSpan
no setterinherited
orange300 → VelocityXTextSpan
no setterinherited
orange400 → VelocityXTextSpan
no setterinherited
orange50 → VelocityXTextSpan
Orange
no setterinherited
orange500 → VelocityXTextSpan
no setterinherited
orange600 → VelocityXTextSpan
no setterinherited
orange700 → VelocityXTextSpan
no setterinherited
orange800 → VelocityXTextSpan
no setterinherited
orange900 → VelocityXTextSpan
no setterinherited
overline → VelocityXTextSpan
Sets TextDecoration as TextDecoration.overline
no setter
pink100 → VelocityXTextSpan
no setterinherited
pink200 → VelocityXTextSpan
no setterinherited
pink300 → VelocityXTextSpan
no setterinherited
pink400 → VelocityXTextSpan
no setterinherited
pink50 → VelocityXTextSpan
Pink
no setterinherited
pink500 → VelocityXTextSpan
no setterinherited
pink600 → VelocityXTextSpan
no setterinherited
pink700 → VelocityXTextSpan
no setterinherited
pink800 → VelocityXTextSpan
no setterinherited
pink900 → VelocityXTextSpan
no setterinherited
purple100 → VelocityXTextSpan
no setterinherited
purple200 → VelocityXTextSpan
no setterinherited
purple300 → VelocityXTextSpan
no setterinherited
purple400 → VelocityXTextSpan
no setterinherited
purple50 → VelocityXTextSpan
Purple
no setterinherited
purple500 → VelocityXTextSpan
no setterinherited
purple600 → VelocityXTextSpan
no setterinherited
purple700 → VelocityXTextSpan
no setterinherited
purple800 → VelocityXTextSpan
no setterinherited
purple900 → VelocityXTextSpan
no setterinherited
red100 → VelocityXTextSpan
no setterinherited
red200 → VelocityXTextSpan
no setterinherited
red300 → VelocityXTextSpan
no setterinherited
red400 → VelocityXTextSpan
no setterinherited
red50 → VelocityXTextSpan
Red
no setterinherited
red500 → VelocityXTextSpan
no setterinherited
red600 → VelocityXTextSpan
no setterinherited
red700 → VelocityXTextSpan
no setterinherited
red800 → VelocityXTextSpan
no setterinherited
red900 → VelocityXTextSpan
no setterinherited
rose100 → VelocityXTextSpan
no setterinherited
rose200 → VelocityXTextSpan
no setterinherited
rose300 → VelocityXTextSpan
no setterinherited
rose400 → VelocityXTextSpan
no setterinherited
rose50 → VelocityXTextSpan
Rose
no setterinherited
rose500 → VelocityXTextSpan
no setterinherited
rose600 → VelocityXTextSpan
no setterinherited
rose700 → VelocityXTextSpan
no setterinherited
rose800 → VelocityXTextSpan
no setterinherited
rose900 → VelocityXTextSpan
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semiBold → VelocityXTextSpan
Sets FontWeight to FontWeight.w600
no setter
sky100 → VelocityXTextSpan
no setterinherited
sky200 → VelocityXTextSpan
no setterinherited
sky300 → VelocityXTextSpan
no setterinherited
sky400 → VelocityXTextSpan
no setterinherited
sky50 → VelocityXTextSpan
Sky
no setterinherited
sky500 → VelocityXTextSpan
no setterinherited
sky600 → VelocityXTextSpan
no setterinherited
sky700 → VelocityXTextSpan
no setterinherited
sky800 → VelocityXTextSpan
no setterinherited
sky900 → VelocityXTextSpan
no setterinherited
slate100 → VelocityXTextSpan
no setterinherited
slate200 → VelocityXTextSpan
no setterinherited
slate300 → VelocityXTextSpan
no setterinherited
slate400 → VelocityXTextSpan
no setterinherited
slate50 → VelocityXTextSpan
Slate
no setterinherited
slate500 → VelocityXTextSpan
no setterinherited
slate600 → VelocityXTextSpan
no setterinherited
slate700 → VelocityXTextSpan
no setterinherited
slate800 → VelocityXTextSpan
no setterinherited
slate900 → VelocityXTextSpan
no setterinherited
stone100 → VelocityXTextSpan
no setterinherited
stone200 → VelocityXTextSpan
no setterinherited
stone300 → VelocityXTextSpan
no setterinherited
stone400 → VelocityXTextSpan
no setterinherited
stone50 → VelocityXTextSpan
Stone
no setterinherited
stone500 → VelocityXTextSpan
no setterinherited
stone600 → VelocityXTextSpan
no setterinherited
stone700 → VelocityXTextSpan
no setterinherited
stone800 → VelocityXTextSpan
no setterinherited
stone900 → VelocityXTextSpan
no setterinherited
teal100 → VelocityXTextSpan
no setterinherited
teal200 → VelocityXTextSpan
no setterinherited
teal300 → VelocityXTextSpan
no setterinherited
teal400 → VelocityXTextSpan
no setterinherited
teal50 → VelocityXTextSpan
teal
no setterinherited
teal500 → VelocityXTextSpan
no setterinherited
teal600 → VelocityXTextSpan
no setterinherited
teal700 → VelocityXTextSpan
no setterinherited
teal800 → VelocityXTextSpan
no setterinherited
teal900 → VelocityXTextSpan
no setterinherited
thin → VelocityXTextSpan
Sets FontWeight to FontWeight.w200
no setter
tight → VelocityXTextSpan
Sets letterSpacing to -1.0
no setter
tighter → VelocityXTextSpan
Sets letterSpacing to -2.0
no setter
tightest → VelocityXTextSpan
Sets letterSpacing to -3.0
no setter
transparent → VelocityXTextSpan
Transparent
no setterinherited
underline → VelocityXTextSpan
Sets TextDecoration as TextDecoration.underline
no setter
uppercase → VelocityXTextSpan
Converts the text to fully uppercase.
no setter
velocityColor ↔ Color?
getter/setter pairinherited
violet100 → VelocityXTextSpan
no setterinherited
violet200 → VelocityXTextSpan
no setterinherited
violet300 → VelocityXTextSpan
no setterinherited
violet400 → VelocityXTextSpan
no setterinherited
violet50 → VelocityXTextSpan
Violet
no setterinherited
violet500 → VelocityXTextSpan
no setterinherited
violet600 → VelocityXTextSpan
no setterinherited
violet700 → VelocityXTextSpan
no setterinherited
violet800 → VelocityXTextSpan
no setterinherited
violet900 → VelocityXTextSpan
no setterinherited
white → VelocityXTextSpan
no setterinherited
wide → VelocityXTextSpan
Sets letterSpacing to 1.0
no setter
wider → VelocityXTextSpan
Sets letterSpacing to 2.0
no setter
widest → VelocityXTextSpan
Sets letterSpacing to 3.0
no setter
yellow100 → VelocityXTextSpan
no setterinherited
yellow200 → VelocityXTextSpan
no setterinherited
yellow300 → VelocityXTextSpan
no setterinherited
yellow400 → VelocityXTextSpan
no setterinherited
yellow50 → VelocityXTextSpan
Yellow
no setterinherited
yellow500 → VelocityXTextSpan
no setterinherited
yellow600 → VelocityXTextSpan
no setterinherited
yellow700 → VelocityXTextSpan
no setterinherited
yellow800 → VelocityXTextSpan
no setterinherited
yellow900 → VelocityXTextSpan
no setterinherited
zinc100 → VelocityXTextSpan
no setterinherited
zinc200 → VelocityXTextSpan
no setterinherited
zinc300 → VelocityXTextSpan
no setterinherited
zinc400 → VelocityXTextSpan
no setterinherited
zinc50 → VelocityXTextSpan
Zinc
no setterinherited
zinc500 → VelocityXTextSpan
no setterinherited
zinc600 → VelocityXTextSpan
no setterinherited
zinc700 → VelocityXTextSpan
no setterinherited
zinc800 → VelocityXTextSpan
no setterinherited
zinc900 → VelocityXTextSpan
no setterinherited

Methods

bodyLarge(BuildContext context) → VelocityXTextSpan
Sets TextTheme body large
bodyMedium(BuildContext context) → VelocityXTextSpan
Sets TextTheme body medium
bodySmall(BuildContext context) → VelocityXTextSpan
Sets TextTheme body small
color(Color color) → VelocityXTextSpan
Set color of the text
displayLarge(BuildContext context) → VelocityXTextSpan
Sets TextTheme display large
displayMedium(BuildContext context) → VelocityXTextSpan
Sets TextTheme display medium
displaySmall(BuildContext context) → VelocityXTextSpan
Sets TextTheme display small
doubleTap(Function function) → VelocityXTextSpan
Set doubleTap func
fontFamily(String family) → VelocityXTextSpan
Set fontFamily for the text
headlineLarge(BuildContext context) → VelocityXTextSpan
Sets TextTheme headline large
headlineMedium(BuildContext context) → VelocityXTextSpan
Sets TextTheme headline medium
headlineSmall(BuildContext context) → VelocityXTextSpan
Sets TextTheme headline small
hexColor(String colorHex) → VelocityXTextSpan
Set color of the text using hexvalue
labelLarge(BuildContext context) → VelocityXTextSpan
Sets TextTheme label large
labelMedium(BuildContext context) → VelocityXTextSpan
Sets TextTheme label medium
labelSmall(BuildContext context) → VelocityXTextSpan
Sets TextTheme label small
letterSpacing(double val) → VelocityXTextSpan
Sets custom letterSpacing with val
lineHeight(double val) → VelocityXTextSpan
Sets custom lineHeight with val
make({Key? key}) → TextSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setChildToColor(VelocityXTextSpan child) → void
inherited
size(double size) → VelocityXTextSpan
Sets fontsize of the text
tap(Function function) → VelocityXTextSpan
Set tap func
textBaseLine(TextBaseline baseline) → VelocityXTextSpan
The common baseline that should be aligned between this text span and its parent text span, or, for the root text spans, with the line box.
textStyle(TextStyle style) → VelocityXTextSpan
Use textStyle to provide custom or any theme style.
titleLarge(BuildContext context) → VelocityXTextSpan
Sets TextTheme title large
titleMedium(BuildContext context) → VelocityXTextSpan
Sets TextTheme title medium
titleSmall(BuildContext context) → VelocityXTextSpan
Sets TextTheme title small
toString() → String
A string representation of this object.
inherited
withChildren(List<TextSpan> children) → VelocityXTextSpan
Set children with list of text spans
wordSpacing(double spacing) → VelocityXTextSpan
The amount of space (in logical pixels) to add at each sequence of white-space (i.e. between each word). A negative value can be used to bring the words closer.

Operators

operator ==(Object other) → bool
The equality operator.
inherited