VxAnimatedBox class

VxAnimatedBox is similar to AnimatedContainer with the advantages of VxBox

Available extensions

Constructors

VxAnimatedBox({Widget? child})

Properties

alignBottomCenter → VxAnimatedBox
no setterinherited
alignBottomLeft → VxAnimatedBox
no setterinherited
alignBottomRight → VxAnimatedBox
no setterinherited
alignCenter → VxAnimatedBox
no setterinherited
alignCenterLeft → VxAnimatedBox
no setterinherited
alignCenterRight → VxAnimatedBox
no setterinherited
alignTopCenter → VxAnimatedBox
no setterinherited
alignTopLeft → VxAnimatedBox
no setterinherited
alignTopRight → VxAnimatedBox
no setterinherited
amber100 → VxAnimatedBox
no setterinherited
amber200 → VxAnimatedBox
no setterinherited
amber300 → VxAnimatedBox
no setterinherited
amber400 → VxAnimatedBox
no setterinherited
amber50 → VxAnimatedBox
Amber
no setterinherited
amber500 → VxAnimatedBox
no setterinherited
amber600 → VxAnimatedBox
no setterinherited
amber700 → VxAnimatedBox
no setterinherited
amber800 → VxAnimatedBox
no setterinherited
amber900 → VxAnimatedBox
no setterinherited
black → VxAnimatedBox
no setterinherited
blue100 → VxAnimatedBox
no setterinherited
blue200 → VxAnimatedBox
no setterinherited
blue300 → VxAnimatedBox
no setterinherited
blue400 → VxAnimatedBox
no setterinherited
blue50 → VxAnimatedBox
Blue
no setterinherited
blue500 → VxAnimatedBox
no setterinherited
blue600 → VxAnimatedBox
no setterinherited
blue700 → VxAnimatedBox
no setterinherited
blue800 → VxAnimatedBox
no setterinherited
blue900 → VxAnimatedBox
no setterinherited
bounceIn → VxAnimatedBox
no setterinherited
bounceInOut → VxAnimatedBox
no setterinherited
bounceOut → VxAnimatedBox
no setterinherited
child → Widget?
final
cyan100 → VxAnimatedBox
no setterinherited
cyan200 → VxAnimatedBox
no setterinherited
cyan300 → VxAnimatedBox
no setterinherited
cyan400 → VxAnimatedBox
no setterinherited
cyan50 → VxAnimatedBox
Cyan
no setterinherited
cyan500 → VxAnimatedBox
no setterinherited
cyan600 → VxAnimatedBox
no setterinherited
cyan700 → VxAnimatedBox
no setterinherited
cyan800 → VxAnimatedBox
no setterinherited
cyan900 → VxAnimatedBox
no setterinherited
decelerate → VxAnimatedBox
no setterinherited
ease → VxAnimatedBox
no setterinherited
easeIn → VxAnimatedBox
no setterinherited
easeInBack → VxAnimatedBox
no setterinherited
easeInCirc → VxAnimatedBox
no setterinherited
easeInCubic → VxAnimatedBox
no setterinherited
easeInExpo → VxAnimatedBox
no setterinherited
easeInOut → VxAnimatedBox
no setterinherited
easeInOutBack → VxAnimatedBox
no setterinherited
easeInOutCirc → VxAnimatedBox
no setterinherited
easeInOutCubic → VxAnimatedBox
no setterinherited
easeInOutExpo → VxAnimatedBox
no setterinherited
easeInOutQuad → VxAnimatedBox
no setterinherited
easeInOutQuart → VxAnimatedBox
no setterinherited
easeInOutQuint → VxAnimatedBox
no setterinherited
easeInOutSine → VxAnimatedBox
no setterinherited
easeInQuad → VxAnimatedBox
no setterinherited
easeInQuart → VxAnimatedBox
no setterinherited
easeInQuint → VxAnimatedBox
no setterinherited
easeInSine → VxAnimatedBox
no setterinherited
easeInToLinear → VxAnimatedBox
no setterinherited
easeOut → VxAnimatedBox
no setterinherited
easeOutBack → VxAnimatedBox
no setterinherited
easeOutCirc → VxAnimatedBox
no setterinherited
easeOutCubic → VxAnimatedBox
no setterinherited
easeOutExpo → VxAnimatedBox
no setterinherited
easeOutQuad → VxAnimatedBox
no setterinherited
easeOutQuart → VxAnimatedBox
no setterinherited
easeOutQuint → VxAnimatedBox
no setterinherited
easeOutSine → VxAnimatedBox
no setterinherited
elasticIn → VxAnimatedBox
no setterinherited
elasticInOut → VxAnimatedBox
no setterinherited
elasticOut → VxAnimatedBox
no setterinherited
emerald100 → VxAnimatedBox
no setterinherited
emerald200 → VxAnimatedBox
no setterinherited
emerald300 → VxAnimatedBox
no setterinherited
emerald400 → VxAnimatedBox
no setterinherited
emerald50 → VxAnimatedBox
Emerald
no setterinherited
emerald500 → VxAnimatedBox
no setterinherited
emerald600 → VxAnimatedBox
no setterinherited
emerald700 → VxAnimatedBox
no setterinherited
emerald800 → VxAnimatedBox
no setterinherited
emerald900 → VxAnimatedBox
no setterinherited
fastLinearToSlowEaseIn → VxAnimatedBox
no setterinherited
fastOutSlowIn → VxAnimatedBox
no setterinherited
fuchsia100 → VxAnimatedBox
no setterinherited
fuchsia200 → VxAnimatedBox
no setterinherited
fuchsia300 → VxAnimatedBox
no setterinherited
fuchsia400 → VxAnimatedBox
no setterinherited
fuchsia50 → VxAnimatedBox
Fuchsia
no setterinherited
fuchsia500 → VxAnimatedBox
no setterinherited
fuchsia600 → VxAnimatedBox
no setterinherited
fuchsia700 → VxAnimatedBox
no setterinherited
fuchsia800 → VxAnimatedBox
no setterinherited
fuchsia900 → VxAnimatedBox
no setterinherited
gray100 → VxAnimatedBox
no setterinherited
gray200 → VxAnimatedBox
no setterinherited
gray300 → VxAnimatedBox
no setterinherited
gray400 → VxAnimatedBox
no setterinherited
gray50 → VxAnimatedBox
Gray
no setterinherited
gray500 → VxAnimatedBox
no setterinherited
gray600 → VxAnimatedBox
no setterinherited
gray700 → VxAnimatedBox
no setterinherited
gray800 → VxAnimatedBox
no setterinherited
gray900 → VxAnimatedBox
no setterinherited
green100 → VxAnimatedBox
no setterinherited
green200 → VxAnimatedBox
no setterinherited
green300 → VxAnimatedBox
no setterinherited
green400 → VxAnimatedBox
no setterinherited
green50 → VxAnimatedBox
Green
no setterinherited
green500 → VxAnimatedBox
no setterinherited
green600 → VxAnimatedBox
no setterinherited
green700 → VxAnimatedBox
no setterinherited
green800 → VxAnimatedBox
no setterinherited
green900 → VxAnimatedBox
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
indigo100 → VxAnimatedBox
no setterinherited
indigo200 → VxAnimatedBox
no setterinherited
indigo300 → VxAnimatedBox
no setterinherited
indigo400 → VxAnimatedBox
no setterinherited
indigo50 → VxAnimatedBox
Indigo
no setterinherited
indigo500 → VxAnimatedBox
no setterinherited
indigo600 → VxAnimatedBox
no setterinherited
indigo700 → VxAnimatedBox
no setterinherited
indigo800 → VxAnimatedBox
no setterinherited
indigo900 → VxAnimatedBox
no setterinherited
lime100 → VxAnimatedBox
no setterinherited
lime200 → VxAnimatedBox
no setterinherited
lime300 → VxAnimatedBox
no setterinherited
lime400 → VxAnimatedBox
no setterinherited
lime50 → VxAnimatedBox
Lime
no setterinherited
lime500 → VxAnimatedBox
no setterinherited
lime600 → VxAnimatedBox
no setterinherited
lime700 → VxAnimatedBox
no setterinherited
lime800 → VxAnimatedBox
no setterinherited
lime900 → VxAnimatedBox
no setterinherited
linear → VxAnimatedBox
no setterinherited
linearToEaseOut → VxAnimatedBox
no setterinherited
neutral100 → VxAnimatedBox
no setterinherited
neutral200 → VxAnimatedBox
no setterinherited
neutral300 → VxAnimatedBox
no setterinherited
neutral400 → VxAnimatedBox
no setterinherited
neutral50 → VxAnimatedBox
Neutral
no setterinherited
neutral500 → VxAnimatedBox
no setterinherited
neutral600 → VxAnimatedBox
no setterinherited
neutral700 → VxAnimatedBox
no setterinherited
neutral800 → VxAnimatedBox
no setterinherited
neutral900 → VxAnimatedBox
no setterinherited
noneShadow → VxAnimatedBox
Shadowing
no setterinherited
orange100 → VxAnimatedBox
no setterinherited
orange200 → VxAnimatedBox
no setterinherited
orange300 → VxAnimatedBox
no setterinherited
orange400 → VxAnimatedBox
no setterinherited
orange50 → VxAnimatedBox
Orange
no setterinherited
orange500 → VxAnimatedBox
no setterinherited
orange600 → VxAnimatedBox
no setterinherited
orange700 → VxAnimatedBox
no setterinherited
orange800 → VxAnimatedBox
no setterinherited
orange900 → VxAnimatedBox
no setterinherited
outerShadow → VxAnimatedBox
no setterinherited
outerShadow2Xl → VxAnimatedBox
no setterinherited
outerShadow3Xl → VxAnimatedBox
no setterinherited
outerShadowLg → VxAnimatedBox
no setterinherited
outerShadowMd → VxAnimatedBox
no setterinherited
outerShadowSm → VxAnimatedBox
Shadowing
no setterinherited
outerShadowXl → VxAnimatedBox
no setterinherited
p0 → VxAnimatedBox
no setterinherited
p1 → VxAnimatedBox
no setterinherited
p12 → VxAnimatedBox
no setterinherited
p16 → VxAnimatedBox
no setterinherited
p20 → VxAnimatedBox
no setterinherited
p24 → VxAnimatedBox
no setterinherited
p3 → VxAnimatedBox
no setterinherited
p32 → VxAnimatedBox
no setterinherited
p4 → VxAnimatedBox
no setterinherited
p48 → VxAnimatedBox
no setterinherited
p64 → VxAnimatedBox
no setterinherited
p8 → VxAnimatedBox
no setterinherited
pink100 → VxAnimatedBox
no setterinherited
pink200 → VxAnimatedBox
no setterinherited
pink300 → VxAnimatedBox
no setterinherited
pink400 → VxAnimatedBox
no setterinherited
pink50 → VxAnimatedBox
Pink
no setterinherited
pink500 → VxAnimatedBox
no setterinherited
pink600 → VxAnimatedBox
no setterinherited
pink700 → VxAnimatedBox
no setterinherited
pink800 → VxAnimatedBox
no setterinherited
pink900 → VxAnimatedBox
no setterinherited
purple100 → VxAnimatedBox
no setterinherited
purple200 → VxAnimatedBox
no setterinherited
purple300 → VxAnimatedBox
no setterinherited
purple400 → VxAnimatedBox
no setterinherited
purple50 → VxAnimatedBox
Purple
no setterinherited
purple500 → VxAnimatedBox
no setterinherited
purple600 → VxAnimatedBox
no setterinherited
purple700 → VxAnimatedBox
no setterinherited
purple800 → VxAnimatedBox
no setterinherited
purple900 → VxAnimatedBox
no setterinherited
px0 → VxAnimatedBox
no setterinherited
px1 → VxAnimatedBox
no setterinherited
px12 → VxAnimatedBox
no setterinherited
px16 → VxAnimatedBox
no setterinherited
px20 → VxAnimatedBox
no setterinherited
px24 → VxAnimatedBox
no setterinherited
px3 → VxAnimatedBox
no setterinherited
px32 → VxAnimatedBox
no setterinherited
px4 → VxAnimatedBox
no setterinherited
px48 → VxAnimatedBox
no setterinherited
px64 → VxAnimatedBox
no setterinherited
px8 → VxAnimatedBox
no setterinherited
py0 → VxAnimatedBox
no setterinherited
py1 → VxAnimatedBox
no setterinherited
py12 → VxAnimatedBox
no setterinherited
py16 → VxAnimatedBox
no setterinherited
py20 → VxAnimatedBox
no setterinherited
py24 → VxAnimatedBox
no setterinherited
py3 → VxAnimatedBox
no setterinherited
py32 → VxAnimatedBox
no setterinherited
py4 → VxAnimatedBox
no setterinherited
py48 → VxAnimatedBox
no setterinherited
py64 → VxAnimatedBox
no setterinherited
py8 → VxAnimatedBox
no setterinherited
radiusGeometry ↔ BorderRadiusGeometry?
getter/setter pairinherited
red100 → VxAnimatedBox
no setterinherited
red200 → VxAnimatedBox
no setterinherited
red300 → VxAnimatedBox
no setterinherited
red400 → VxAnimatedBox
no setterinherited
red50 → VxAnimatedBox
Red
no setterinherited
red500 → VxAnimatedBox
no setterinherited
red600 → VxAnimatedBox
no setterinherited
red700 → VxAnimatedBox
no setterinherited
red800 → VxAnimatedBox
no setterinherited
red900 → VxAnimatedBox
no setterinherited
rose100 → VxAnimatedBox
no setterinherited
rose200 → VxAnimatedBox
no setterinherited
rose300 → VxAnimatedBox
no setterinherited
rose400 → VxAnimatedBox
no setterinherited
rose50 → VxAnimatedBox
Rose
no setterinherited
rose500 → VxAnimatedBox
no setterinherited
rose600 → VxAnimatedBox
no setterinherited
rose700 → VxAnimatedBox
no setterinherited
rose800 → VxAnimatedBox
no setterinherited
rose900 → VxAnimatedBox
no setterinherited
rounded → VxAnimatedBox
no setterinherited
roundedFull → VxAnimatedBox
Sets the decorated box as circular.
no setter
roundedLg → VxAnimatedBox
no setterinherited
roundedNone → VxAnimatedBox
no setterinherited
roundedSM → VxAnimatedBox
no setterinherited
roundedValue ↔ double?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → VxAnimatedBox
Shadowing
no setterinherited
shadow2xl → VxAnimatedBox
To give twice extra large shadow.
no setterinherited
shadow3xl → VxAnimatedBox
To give thrice extra large shadow.
no setterinherited
shadow4xl → VxAnimatedBox
To give 4x extra large shadow.
no setterinherited
shadow5xl → VxAnimatedBox
To give 5x extra large shadow.
no setterinherited
shadowLg → VxAnimatedBox
To give large shadow.
no setterinherited
shadowMax → VxAnimatedBox
To give max shadow.
no setterinherited
shadowMd → VxAnimatedBox
To give medium shadow.
no setterinherited
shadowSm → VxAnimatedBox
To give small shadow.
no setterinherited
shadowXl → VxAnimatedBox
To give extra large shadow.
no setterinherited
shadowXs → VxAnimatedBox
To give extra small shadow.
no setterinherited
sky100 → VxAnimatedBox
no setterinherited
sky200 → VxAnimatedBox
no setterinherited
sky300 → VxAnimatedBox
no setterinherited
sky400 → VxAnimatedBox
no setterinherited
sky50 → VxAnimatedBox
Sky
no setterinherited
sky500 → VxAnimatedBox
no setterinherited
sky600 → VxAnimatedBox
no setterinherited
sky700 → VxAnimatedBox
no setterinherited
sky800 → VxAnimatedBox
no setterinherited
sky900 → VxAnimatedBox
no setterinherited
slate100 → VxAnimatedBox
no setterinherited
slate200 → VxAnimatedBox
no setterinherited
slate300 → VxAnimatedBox
no setterinherited
slate400 → VxAnimatedBox
no setterinherited
slate50 → VxAnimatedBox
Slate
no setterinherited
slate500 → VxAnimatedBox
no setterinherited
slate600 → VxAnimatedBox
no setterinherited
slate700 → VxAnimatedBox
no setterinherited
slate800 → VxAnimatedBox
no setterinherited
slate900 → VxAnimatedBox
no setterinherited
slowMiddle → VxAnimatedBox
no setterinherited
stone100 → VxAnimatedBox
no setterinherited
stone200 → VxAnimatedBox
no setterinherited
stone300 → VxAnimatedBox
no setterinherited
stone400 → VxAnimatedBox
no setterinherited
stone50 → VxAnimatedBox
Stone
no setterinherited
stone500 → VxAnimatedBox
no setterinherited
stone600 → VxAnimatedBox
no setterinherited
stone700 → VxAnimatedBox
no setterinherited
stone800 → VxAnimatedBox
no setterinherited
stone900 → VxAnimatedBox
no setterinherited
teal100 → VxAnimatedBox
no setterinherited
teal200 → VxAnimatedBox
no setterinherited
teal300 → VxAnimatedBox
no setterinherited
teal400 → VxAnimatedBox
no setterinherited
teal50 → VxAnimatedBox
teal
no setterinherited
teal500 → VxAnimatedBox
no setterinherited
teal600 → VxAnimatedBox
no setterinherited
teal700 → VxAnimatedBox
no setterinherited
teal800 → VxAnimatedBox
no setterinherited
teal900 → VxAnimatedBox
no setterinherited
transparent → VxAnimatedBox
Transparent
no setterinherited
velocityAlignment ↔ Alignment?
getter/setter pairinherited
velocityColor ↔ Color?
getter/setter pairinherited
velocityCurve ↔ Curve?
getter/setter pairinherited
velocityDuration ↔ Duration?
getter/setter pairinherited
velocityGradient ↔ Gradient?
getter/setter pairinherited
velocityPadding ↔ EdgeInsetsGeometry?
Provides Padding
getter/setter pairinherited
velocityShadow ↔ List<BoxShadow>?
getter/setter pairinherited
violet100 → VxAnimatedBox
no setterinherited
violet200 → VxAnimatedBox
no setterinherited
violet300 → VxAnimatedBox
no setterinherited
violet400 → VxAnimatedBox
no setterinherited
violet50 → VxAnimatedBox
Violet
no setterinherited
violet500 → VxAnimatedBox
no setterinherited
violet600 → VxAnimatedBox
no setterinherited
violet700 → VxAnimatedBox
no setterinherited
violet800 → VxAnimatedBox
no setterinherited
violet900 → VxAnimatedBox
no setterinherited
white → VxAnimatedBox
no setterinherited
willRender ↔ bool
getter/setter pairinherited
yellow100 → VxAnimatedBox
no setterinherited
yellow200 → VxAnimatedBox
no setterinherited
yellow300 → VxAnimatedBox
no setterinherited
yellow400 → VxAnimatedBox
no setterinherited
yellow50 → VxAnimatedBox
Yellow
no setterinherited
yellow500 → VxAnimatedBox
no setterinherited
yellow600 → VxAnimatedBox
no setterinherited
yellow700 → VxAnimatedBox
no setterinherited
yellow800 → VxAnimatedBox
no setterinherited
yellow900 → VxAnimatedBox
no setterinherited
zinc100 → VxAnimatedBox
no setterinherited
zinc200 → VxAnimatedBox
no setterinherited
zinc300 → VxAnimatedBox
no setterinherited
zinc400 → VxAnimatedBox
no setterinherited
zinc50 → VxAnimatedBox
Zinc
no setterinherited
zinc500 → VxAnimatedBox
no setterinherited
zinc600 → VxAnimatedBox
no setterinherited
zinc700 → VxAnimatedBox
no setterinherited
zinc800 → VxAnimatedBox
no setterinherited
zinc900 → VxAnimatedBox
no setterinherited

Methods

alignment(Alignment val) → VxAnimatedBox
inherited
animDuration(Duration duration) → VxAnimatedBox
Sets the duration property of the animated box.
bgImage(DecorationImage image) → VxAnimatedBox
Sets the background image to the decorated box.
border({Color color = Colors.black, double width = 1.0, BorderStyle style = BorderStyle.solid}) → VxAnimatedBox
Sets the border of the Box.
bottomLeftRounded({double? value}) → VxAnimatedBox
inherited
bottomRightRounded({double? value}) → VxAnimatedBox
inherited
bottomRounded({double? value}) → VxAnimatedBox
inherited
color(Color color) → VxAnimatedBox
Sets the color property of the box.
customRounded(BorderRadiusGeometry geometry) → VxAnimatedBox
inherited
days({required int days}) → VxAnimatedBox
inherited
gradientFrom({required Color from, List<double>? stops}) → VxAnimatedBox
inherited
gradientFromTo({required Color from, required Color to, List<double>? stops}) → VxAnimatedBox
inherited
gradientTo({required Color to, List<double>? stops}) → VxAnimatedBox
inherited
gradientVia({required Color from, required Color via, required Color to, List<double>? stops}) → VxAnimatedBox
inherited
height(double val) → VxAnimatedBox
Sets the height property of the box.
hexColor(String colorHex) → VxAnimatedBox
Sets the color property of the box using the hex color value.
hours({required int hours}) → VxAnimatedBox
inherited
leftRounded({double? value}) → VxAnimatedBox
inherited
linearGradient(List<Color> colors) → VxAnimatedBox
Sets the linear gradient to the decorated box.
make({Key? key}) → Widget
makeCentered({Key? key}) → Widget

Available on VxWidgetBuilder<Widget>, provided by the VxCenterBuilderExtension extension

Extension method to directly access Center with any Vx widget without wrapping or with dot operator.
margin(EdgeInsetsGeometry val) → VxAnimatedBox
Sets the margin property of the box.
microSeconds({required int microSec}) → VxAnimatedBox
inherited
milliSeconds({required int milliSec}) → VxAnimatedBox
inherited
minutes({required int mins}) → VxAnimatedBox
inherited
neumorphic({Color? color, VxCurve curve = VxCurve.concave, double elevation = 12.0}) → VxAnimatedBox
Use this to convert your box to the neumorphic design. Use it wisely.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding(EdgeInsetsGeometry val) → VxAnimatedBox
Sets the padding property of the box.
radialGradient(List<Color> colors) → VxAnimatedBox
Sets the radial gradient to the decorated box.
rightRounded({double? value}) → VxAnimatedBox
inherited
seconds({required int sec}) → VxAnimatedBox
inherited
setChildForAlignment(VxAnimatedBox child) → void
inherited
setChildForCurve(VxAnimatedBox child) → void
inherited
setChildForDuration(VxAnimatedBox child) → void
inherited
setChildForRender(VxAnimatedBox child) → void
inherited
setChildForShadow(VxAnimatedBox child) → void
inherited
setChildToColor(VxAnimatedBox child) → void
inherited
setChildToGradient(VxAnimatedBox child) → void
inherited
setChildToPad(VxAnimatedBox child) → void
inherited
setChildToRound(VxAnimatedBox child) → void
inherited
shadowOutline({Color? outlineColor}) → VxAnimatedBox
To give shadow with some outline color.
size(double width, double height) → VxAnimatedBox
Sets the size (width & height) property of the box.
sizePCT({required BuildContext context, required double widthPCT, required double heightPCT}) → VxAnimatedBox
Sets the size (width & height in percentage) property of the box.
square(double val) → VxAnimatedBox
Sets the height and width as square of the box.
sweepGradient(List<Color> colors) → VxAnimatedBox
Sets the sweep gradient to the decorated box.
topLeftRounded({double? value}) → VxAnimatedBox
inherited
topRightRounded({double? value}) → VxAnimatedBox
inherited
topRounded({double? value}) → VxAnimatedBox
inherited
toString() → String
A string representation of this object.
inherited
transform(Matrix4 val) → VxAnimatedBox
transforming
velocityDecoration(Color color, VxCurve curveType, double elevation) → VxNeumorph
inherited
when(bool condition) → VxAnimatedBox
Uses when clause to render the widget only when the condition is true.
inherited
width(double val) → VxAnimatedBox
Sets the width property of the box.
withDecoration(BoxDecoration decoration) → VxAnimatedBox
Provide a custom DecoratedBox
withGradient(Gradient gradient) → VxAnimatedBox
Sets the defined gradient to the decorated box.
withRounded({double value = 15.0}) → VxAnimatedBox
inherited
withShadow(List<BoxShadow> shadows) → VxAnimatedBox
To give custom shadow.

Operators

operator ==(Object other) → bool
The equality operator.
inherited