VxFilter class

VxFilter is used to apply different color filters to the child widget.

Available extensions

Constructors

VxFilter({required Widget child})

Properties

blackAndWhite → VxFilter
Returns the black and white filter matrix.
no setter
blue → VxFilter
Returns the blue filter matrix.
no setter
child → Widget
final
coldLife → VxFilter
Returns the cold life filter matrix.
no setter
hashCode → int
The hash code for this object.
no setterinherited
milk → VxFilter
Returns the milk filter matrix.
no setter
myMatrix ↔ List<double>
getter/setter pair
noFilter → VxFilter
Returns the no filter matrix.
no setter
oldTimes → VxFilter
Returns the old times filter matrix.
no setter
pink → VxFilter
Returns the pink filter matrix.
no setter
polaroid → VxFilter
Returns the polaroid filter matrix.
no setter
purple → VxFilter
Returns the purple filter matrix.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sepia → VxFilter
Returns the sepia filter matrix.
no setter
yellow → VxFilter
Returns the yellow filter matrix.
no setter

Methods

blend(Color color, BlendMode blendMode) → VxFilter
Returns the color filter mode after blending with a given color and blend mode.
make({Key? key}) → Widget
makeCentered({Key? key}) → Widget

Available on VxWidgetBuilder<Widget>, provided by the VxCenterBuilderExtension extension

Extension method to directly access Center with any Vx widget without wrapping or with dot operator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomFilter(List<double> filterMatrix) → VxFilter
Returns the custom filter matrix.
setFilter(VxColorFilter filter) → VxFilter
Returns the predefined filter matrix.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited