VxNeumorph class

VxNeumorph class to accept list of shadows and a Gradient

Constructors

VxNeumorph(List<BoxShadow> shadows, Gradient? gradient)

Properties

gradient → Gradient?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<BoxShadow>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited