VxNumExtension extension

Extension Methods & Widgets for the numbers

on

Properties

acos → double

Available on num, provided by the VxNumExtension extension

no setter
asin → double

Available on num, provided by the VxNumExtension extension

no setter
cos → double

Available on num, provided by the VxNumExtension extension

no setter
exp → double

Available on num, provided by the VxNumExtension extension

no setter
heightBox → Widget

Available on num, provided by the VxNumExtension extension

Converts the number into a SizedBox with the height as that number.
no setter
isEven → bool

Available on num, provided by the VxNumExtension extension

Returns if the number is even
no setter
isNegative → bool

Available on num, provided by the VxNumExtension extension

Returns if the number is negative
no setter
isNotNull → bool?

Available on num, provided by the VxNumExtension extension

Check if the number is not null
no setter
isNull → bool?

Available on num, provided by the VxNumExtension extension

Check if the number is null
no setter
isOdd → bool

Available on num, provided by the VxNumExtension extension

Returns if the number is odd
no setter
isPositive → bool

Available on num, provided by the VxNumExtension extension

Returns if the number is positive
no setter
length → int

Available on num, provided by the VxNumExtension extension

num long
no setter
log → double

Available on num, provided by the VxNumExtension extension

no setter
numberOfDigits → int

Available on num, provided by the VxNumExtension extension

Returns number of digits in this number
no setter
numCurrency → String

Available on num, provided by the VxNumExtension extension

Format numeric currency
no setter
sqrt → double

Available on num, provided by the VxNumExtension extension

no setter
squareBox → Widget

Available on num, provided by the VxNumExtension extension

Converts the number into a SizedBox with the width & height as that number.
no setter
tan → double

Available on num, provided by the VxNumExtension extension

no setter
text → VxTextBuilder

Available on num, provided by the VxNumExtension extension

Get Text Widget for the String
no setter
widthBox → Widget

Available on num, provided by the VxNumExtension extension

Widgets
no setter

Methods

atan2(num value) → double

Available on num, provided by the VxNumExtension extension

contains(Pattern other, [int startIndex = 0]) → bool

Available on num, provided by the VxNumExtension extension

Does it contain other
fromMicrosecondsSinceEpoch({bool isUtc = false}) → DateTime?

Available on num, provided by the VxNumExtension extension

DateTime from microseconds
fromMillisecondsSinceEpoch({bool isUtc = false}) → DateTime?

Available on num, provided by the VxNumExtension extension

DateTime from milliseconds
generate<T>(T generator(int index), {bool growable = true}) → List<T>

Available on num, provided by the VxNumExtension extension

Create a List of the specified length
max<T extends num>(T value) → T

Available on num, provided by the VxNumExtension extension

min<T extends num>(T value) → T

Available on num, provided by the VxNumExtension extension

numCurrencyWithLocale({String locale = "en_US"}) → String

Available on num, provided by the VxNumExtension extension

Format numeric currency with provided locale
padLeft(int width, [String padding = ' ']) → String

Available on num, provided by the VxNumExtension extension

toDoubleStringAsFixed({int digit = 2}) → String

Available on num, provided by the VxNumExtension extension

Use this extension method to get fixed values after decimal with defined length.
toDoubleStringAsPrecised({int length = 4}) → String

Available on num, provided by the VxNumExtension extension

Use this extension method to get precised values after decimal with defined length.
toFileSize() → String

Available on num, provided by the VxNumExtension extension

get file size for a number