VxSizeConfig class

Constructors

VxSizeConfig({double? xsmall, double? small, double? medium, double? large, double? xlarge})

Properties

hashCode → int
The hash code for this object.
no setterinherited
large → double?
final
medium → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
small → double?
final
xlarge → double?
final
xsmall → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited