VxStringExtension extension

Extension Methods & Widgets for the strings

on

Properties

capitalized → String

Available on String, provided by the VxStringExtension extension

from 'foo' to 'Foo'
no setter
eliminateFirst → String

Available on String, provided by the VxStringExtension extension

Removes first element
no setter
eliminateLast → String

Available on String, provided by the VxStringExtension extension

Removes last element
no setter
isEmpty → bool

Available on String, provided by the VxStringExtension extension

Return a bool if the string is null or empty
no setter
isJsonDecodable → bool

Available on String, provided by the VxStringExtension extension

Check if string is json decodable
no setter
isNotBlank → bool

Available on String, provided by the VxStringExtension extension

Returns true if s is neither null, empty nor is solely made of whitespace characters.
no setter
lowerCamelCase → String

Available on String, provided by the VxStringExtension extension

From 'foo_bar' to 'fooBar'
no setter
numCurrency → String

Available on String, provided by the VxStringExtension extension

Format numeric currency
no setter
orEmpty → String

Available on String, provided by the VxStringExtension extension

Returns the string if it is not null, or the empty string otherwise
no setter
richText → VxRichText

Available on String, provided by the VxStringExtension extension

Get RichText Widget for the String
no setter
selectableText → VxSelectableTextBuilder

Available on String, provided by the VxStringExtension extension

Get SelectableText Widget for the String
no setter
snakeCase → String

Available on String, provided by the VxStringExtension extension

from fooBar to foo_bar
no setter
text → VxTextBuilder

Available on String, provided by the VxStringExtension extension

Get Text Widget for the String
no setter
textSpan → VelocityXTextSpan

Available on String, provided by the VxStringExtension extension

Get TextSpan for the String
no setter
toDecodedBase64 → String

Available on String, provided by the VxStringExtension extension

Base64 decryption
no setter
toEncodedBase64 → String

Available on String, provided by the VxStringExtension extension

Base64 encryption
no setter
upperCamelCase → String

Available on String, provided by the VxStringExtension extension

from 'foo_bar' to 'FooBar'
no setter
utf8Encode → List<int>

Available on String, provided by the VxStringExtension extension

Perform utf8 encoding
no setter
utf8ToList → List<int>

Available on String, provided by the VxStringExtension extension

utf8ToList
no setter

Methods

allWordsCapitilize() → String

Available on String, provided by the VxStringExtension extension

Capitalize all words inside a string
compareToIgnoringCase(String other) → int

Available on String, provided by the VxStringExtension extension

Returns a value according to the contract for Comparator indicating the ordering between this and other, ignoring letter case.
filterChars() → String

Available on String, provided by the VxStringExtension extension

firstLetterUpperCase() → String

Available on String, provided by the VxStringExtension extension

Returns first letter of the string as Caps eg -> Flutter
formatDigitPattern({int digit = 4, String pattern = ' '}) → String

Available on String, provided by the VxStringExtension extension

Add pattern every x bits
formatDigitPatternEnd(String text, {int digit = 4, String pattern = ' '}) → String

Available on String, provided by the VxStringExtension extension

Add pattern every x bits, starting from the end
hidePartial({int begin = 0, int? end, String replace = '*'}) → String?

Available on String, provided by the VxStringExtension extension

Replaces chars of the given String s with replace.
ifEmpty(Function action) → String

Available on String, provided by the VxStringExtension extension

insert(String other, int index) → String

Available on String, provided by the VxStringExtension extension

Returns a copy of this with other inserted starting at index.
isCreditCardValid() → bool

Available on String, provided by the VxStringExtension extension

Checks the validity of the credit/debit card number using the Luhn algorithm.
isDigit() → bool

Available on String, provided by the VxStringExtension extension

Check whether a string is digit or not
isLetter() → bool

Available on String, provided by the VxStringExtension extension

isNumber() → bool

Available on String, provided by the VxStringExtension extension

Check whether a string is a number or not
isRtlLanguage() → bool

Available on String, provided by the VxStringExtension extension

Check if String is Right to Left Language
isSymbol() → bool

Available on String, provided by the VxStringExtension extension

numCurrencyWithLocale({String locale = "en_US"}) → String

Available on String, provided by the VxStringExtension extension

Format numeric currency with provided locale
prepend(String other) → String

Available on String, provided by the VxStringExtension extension

Returns the concatenation of other and this.
removeAllWhiteSpace() → String

Available on String, provided by the VxStringExtension extension

Returns a String without white space at all "hello world" // helloworld
reverse() → String

Available on String, provided by the VxStringExtension extension

Returns this with characters in reverse order.
toDate() → DateTime?

Available on String, provided by the VxStringExtension extension

Convert DateString to DateTime Object
toDateString([String? locale]) → String

Available on String, provided by the VxStringExtension extension

Converts YYMMDD HH:MM Date to a fully DateString representation, if you need to use locale, dont forget to use initializeDateFormatting in your main() function.
validateEmail() → bool

Available on String, provided by the VxStringExtension extension

Uses regex to check if the provided string is a valid email address or not