VxTimelineModel class

Constructors

VxTimelineModel({required int id, required String heading, required String description, String? actionUrl})
const

Properties

actionUrl → String?
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
heading → String
final
id → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited