NullablePreferenceItem<T> class

Inheritance
Implementers

Constructors

NullablePreferenceItem(String key, [T? defaultValue])

Properties

defaultValue → T?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(T? value) → void
inherited
delete() → Future<bool>
inherited
get() → T?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T? value) → Future<bool>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited