PreferenceItem<T> class

Implementers

Constructors

PreferenceItem(String key, T defaultValue)

Properties

defaultValue → T
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(T value) → void
delete() → Future<bool>
get() → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T value) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited