Language enum

Inheritance
Available extensions

Values

korean → const Language
const Language(Locale('ko'), '$basePath/flag/flag_kr.png')
english → const Language
const Language(Locale('en'), '$basePath/flag/flag_us.png')

Properties

flagPath → String
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
locale → Locale
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

find(String key) → Language

Constants

values → const List<Language>
A constant List of the values in this enum, in order of their declaration.