CustomGoogleFont class

Constructors

CustomGoogleFont(String downloadUrl, String expectedFileHash, int expectedLength)

Properties

downloadUrl → String
final
expectedFileHash → String
finalinherited
expectedLength → int
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited