RoundButtonTheme enum

Inheritance
Available extensions

Values

blue → const RoundButtonTheme
const RoundButtonTheme(AppColors.blue, Colors.white, AppColors.blue, backgroundColorProvider: blueColorProvider)
whiteWithBlueBorder → const RoundButtonTheme
const RoundButtonTheme(Colors.white, AppColors.darkBlue, AppColors.blue, backgroundColorProvider: blueColorProvider)
const RoundButtonTheme(AppColors.blue, Colors.white, Colors.black, backgroundColorProvider: blueColorProvider)

Properties

backgroundColorProvider → Color Function(BuildContext context)?
RoundButtonTheme 안에서 Custome Theme 분기가 필요하다면 이렇게 함수로 사용
final
bgColor → Color
final
borderColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color
final
textColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RoundButtonTheme>
A constant List of the values in this enum, in order of their declaration.