TextBadgeTheme class

Constructors

TextBadgeTheme.basic(BuildContext context)
factory
TextBadgeTheme.large(BuildContext context)
factory

Properties

backgroundColor → Color
final
borderColor → Color
final
borderRadius → double
final
borderWidth → double?
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalPadding → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color
final
verticalPadding → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited