ApiError class

Constructors

ApiError({int? statusCode, bool isApplicationError = false, required String message})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isApplicationError ↔ bool
getter/setter pair
message ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createErrorResult(dynamic e) → dynamic