SimpleResult<SuccessType, FailureType> class

Constructors

SimpleResult()

Properties

failureData → FailureType
no setter
hashCode → int
The hash code for this object.
no setterinherited
isFailure → bool
no setter
isSuccess → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successData → SuccessType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runIfFailure(FutureOr<void> function(FailureType error)) → SimpleResult
runIfFailureAsync(FutureOr<void> function(FailureType error)) → FutureOr<SimpleResult>
runIfSuccess(FutureOr<void> function(SuccessType data)) → SimpleResult
runIfSuccessAsync(FutureOr<void> function(SuccessType data)) → FutureOr<SimpleResult>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

failure<SuccessType, FailureType>([FailureType? data]) → _Failure<SuccessType, FailureType>
success<SuccessType, FailureType>([SuccessType? data]) → _Success<SuccessType, FailureType>