Package class

Annotations
  • @freezed

Constructors

Package({required String name, required String description, String? homepage, String? repository, required List<String> authors, required String version, String? license, @Default.new(false) bool isMarkdown, @Default.new(false) bool isSdk, @Default.new(false) bool isDirectDependency})
factory
Package.fromJson(Map<String, Object?> json)
factory

Properties

authors → List<String>
no setterinherited
copyWith → $PackageCopyWith<Package>
Create a copy of Package with the given fields replaced by the non-null parameter values.
no setterinherited
description → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
homepage → String?
no setterinherited
isDirectDependency → bool
no setterinherited
isMarkdown → bool
no setterinherited
isSdk → bool
no setterinherited
license → String?
no setterinherited
name → String
no setterinherited
repository → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Package to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited