TabItem enum

Inheritance
Available extensions

Values

home → const TabItem
const TabItem(Icons.home, '홈', HomeFragment())
favorite → const TabItem
const TabItem(Icons.star, '즐겨찾기', FavoriteFragment(isShowBackButton: false))

Properties

activeIcon IconData
final
firstPage Widget
final
hashCode int
The hash code for this object.
no setterinherited
inActiveIcon IconData
final
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNavigationBarItem(BuildContext context, {required bool isActivated}) BottomNavigationBarItem
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TabItem>
A constant List of the values in this enum, in order of their declaration.